### Title

notion Scraper

### Descrption

* With notion Scraper you can scrape search results and extract the contents produced by the search result.
* In notion scraper it will scrape the data present of the website and give json data which contains the details of the contents on the website.

### JSON sample data
```sh
{
    "Scraper_repeat_data_0": [
        {
            "description": "Advanced features for your org",
            "item_link": "/enterprise",
            "label": "Enterprise"
        },
        {
            "description": "Run your team on one tool",
            "item_link": "/teams",
            "label": "Small business"
        }
```

[Click Here for more](https://datakund-scraper.s3.amazonaws.com/datakund_27I5J6QP4PSXIKW_json.json)

### Run Scraper
```sh
from notion_scraper import *
link="https://www.notion.so/mobile"
data=run_notion_scraper(link)
```

### How it works?
* It takes URL of notion page with a search keyword to scrape the data.
* It generates the json data which contains the information of the notion search result.
* It gives the every detail present inside website in the form of json data.


### Examples
Below are some of the examples of URLs using which you can scrape:

* [Example 1](https://www.notion.so/desktop)

* [Example2](https://www.notion.so/mobile)


### Queries/ Feedback
If you have some queries or feedback please contact us at following    
[Telegram](https://t.me/datakund)  
[Email](abhishek@datakund.com)









